GDCM binaries have moved !
--------------------------

They are now automatically uploaded to github:

[github release](https://github.com/malaterre/GDCM/releases/tag/vVERSION)

They are build using travis and appveyor automatically

As a side note the old zip (source) file is not available anymore on sf.net,
please see instead on github.
